@@ -1,5 +1,5 @@
 from . import Logger, Utils
-import json as __json
+import json
 import time
 from datetime import datetime
 import requests
@@ -64,7 +64,7 @@ class Host():
             parameters["os"] = self.getOS()
         if self.data:
             parameters["data"] = self.getData()
-        Logger.printMessage(message='{data}'.format(data=__json.dumps(parameters, indent=4, sort_keys=True), debug_core=True))
+        Logger.printMessage(message='{data}'.format(data=json.dumps(parameters, indent=4, sort_keys=True), debug_core=True))
         return parameters
     
     def setTarget(self, id):
@@ -461,7 +461,7 @@ class RequestHandler:
 				return None
 		except requests.exceptions.ConnectionError:
 			raise requests.exceptions.ConnectionError
-		except __json.decoder.JSONDecodeError:
+		except json.decoder.JSONDecodeError:
 			return None
 
 	def header_maker(self, mode):
@@ -1170,7 +1170,7 @@ class InstagramEndPoints:
         return self.ACCOUNT_JSON_PRIVATE_INFO_BY_ID.format( s=urllib.parse.quote_plus(str(account_id)) )
 
     def get_account_medias_json_link(self, variables):
-        return self.ACCOUNT_MEDIAS.format( s=urllib.parse.quote_plus(__json.dumps(variables, separators=(',', ':'))) )
+        return self.ACCOUNT_MEDIAS.format( s=urllib.parse.quote_plus(json.dumps(variables, separators=(',', ':'))) )
 
     def get_media_page_link(self, code):
         return self.MEDIA_LINK.format( s=urllib.parse.quote_plus(code) )
@@ -1188,13 +1188,13 @@ class InstagramEndPoints:
         return self.GENERAL_SEARCH.format( s=urllib.parse.quote_plus(query) )
 
     def get_comments_before_comments_id_by_code(self, variables):
-        return self.COMMENTS_BEFORE_COMMENT_ID_BY_CODE.format( s=urllib.parse.quote_plus(__json.dumps(variables, separators=(',', ':'))) )
+        return self.COMMENTS_BEFORE_COMMENT_ID_BY_CODE.format( s=urllib.parse.quote_plus(json.dumps(variables, separators=(',', ':'))) )
 
     def get_last_likes_by_code_old(self, code, count, last_like_id):
         return self.LIKES_BY_SHORTCODE_OLD.format( s=urllib.parse.quote_plus(code), s2=urllib.parse.quote_plus(str(count)), s3=urllib.parse.quote_plus(str(last_like_id)) )
 
     def get_last_likes_by_code(self, variables):
-        return self.LIKES_BY_SHORTCODE.format( s=urllib.parse.quote_plus(__json.dumps(variables, separators=(',', ':'))) )
+        return self.LIKES_BY_SHORTCODE.format( s=urllib.parse.quote_plus(json.dumps(variables, separators=(',', ':'))) )
 
     def get_follow_url(self, account_id):
         return self.FOLLOW_URL.format( s=urllib.parse.quote_plus(account_id) )
@@ -1215,7 +1215,7 @@ class InstagramEndPoints:
         return url
 
     def get_followers_json_link(self, variables):
-        return self.FOLLOWERS_URL.format( s=urllib.parse.quote_plus(__json.dumps(variables, separators=(',', ':'))) )
+        return self.FOLLOWERS_URL.format( s=urllib.parse.quote_plus(json.dumps(variables, separators=(',', ':'))) )
 
     def get_following_json_link_old(self, account_id, count, after=''):
         url = self.FOLLOWING_URL_OLD.replace(
@@ -1230,10 +1230,10 @@ class InstagramEndPoints:
         return url
 
     def get_following_json_link(self, variables):
-        return self.FOLLOWING_URL.format( s=urllib.parse.quote_plus(__json.dumps(variables, separators=(',', ':'))) )
+        return self.FOLLOWING_URL.format( s=urllib.parse.quote_plus(json.dumps(variables, separators=(',', ':'))) )
 
     def get_user_stories_link(self, ):
-        return self.get_graph_ql_url(self.USER_STORIES, {'variables': __json.dumps([], separators=(',', ':'))})
+        return self.get_graph_ql_url(self.USER_STORIES, {'variables': json.dumps([], separators=(',', ':'))})
 
     def get_graph_ql_url(self, query_id, parameters):
         url = self.GRAPH_QL_QUERY_URL.format( s=urllib.parse.quote_plus(query_id) )
@@ -1245,7 +1245,7 @@ class InstagramEndPoints:
         return url
 
     def get_stories_link(self, variables):
-        return self.get_graph_ql_url(self.STORIES, {'variables': __json.dumps(variables, separators=(',', ':'))})
+        return self.get_graph_ql_url(self.STORIES, {'variables': json.dumps(variables, separators=(',', ':'))})
 
     def get_like_url(self, media_id):
         return self.LIKE_URL.format( s=urllib.parse.quote_plus(str(media_id)) )
